summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCharles Harris <charlesr.harris@gmail.com>2020-07-10 08:20:05 -0600
committerGitHub <noreply@github.com>2020-07-10 08:20:05 -0600
commit34b748bbce51f880c712312b9c2d37a3560628c0 (patch)
tree369d7350a9203b7978eea5df9b5858cf65bb4234
parent58da484abf6f466a9e8bf55c188cb5b501d31ceb (diff)
parentfc9d862f0cec6d9dc83acef54a66732dfdb813a3 (diff)
downloadnumpy-34b748bbce51f880c712312b9c2d37a3560628c0.tar.gz
Merge pull request #16793 from mattip/cython0.29.21
BLD, MAINT: update cython to 0.29.21
-rw-r--r--.travis.yml2
-rw-r--r--INSTALL.rst.txt2
-rw-r--r--numpy/core/tests/test_cython.py4
-rw-r--r--numpy/random/tests/test_extending.py4
-rw-r--r--pyproject.toml2
-rw-r--r--test_requirements.txt2
-rwxr-xr-xtools/cythonize.py4
7 files changed, 10 insertions, 10 deletions
diff --git a/.travis.yml b/.travis.yml
index 4cb6bd3f7..b3d8adfa5 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -36,7 +36,7 @@ jobs:
- stage: Comprehensive tests
python: 3.6
- python: 3.7
-# - python: 3.9-dev
+ - python: 3.9-dev
- python: 3.6
env: USE_DEBUG=1
diff --git a/INSTALL.rst.txt b/INSTALL.rst.txt
index 2b9226751..1c33060a6 100644
--- a/INSTALL.rst.txt
+++ b/INSTALL.rst.txt
@@ -20,7 +20,7 @@ Building NumPy requires the following installed software:
e.g., on Debian/Ubuntu one needs to install both `python3` and
`python3-dev`. On Windows and macOS this is normally not an issue.
-2) Cython >= 0.29.14
+2) Cython >= 0.29.21
3) pytest__ (optional) 1.15 or later
diff --git a/pyproject.toml b/pyproject.toml
index d81b731d3..9dfc599e8 100644
--- a/pyproject.toml
+++ b/pyproject.toml
@@ -3,7 +3,7 @@
requires = [
"setuptools",
"wheel",
- "Cython>=0.29.14", # Note: keep in sync with tools/cythonize.py
+ "Cython>=0.29.21", # Note: keep in sync with tools/cythonize.py
]
diff --git a/test_requirements.txt b/test_requirements.txt
index d7698609f..7afc6820b 100644
--- a/test_requirements.txt
+++ b/test_requirements.txt
@@ -1,4 +1,4 @@
-cython==0.29.19
+cython==0.29.21
hypothesis==5.19.0
pytest==5.4.3
pytz==2020.1
diff --git a/numpy/core/tests/test_cython.py b/numpy/core/tests/test_cython.py
index 92ef09c9b..63524b269 100644
--- a/numpy/core/tests/test_cython.py
+++ b/numpy/core/tests/test_cython.py
@@ -15,11 +15,11 @@ except ImportError:
else:
from distutils.version import LooseVersion
# Cython 0.29.14 is required for Python 3.8 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.
# Note: keep in sync with the one in pyproject.toml
- required_version = LooseVersion("0.29.14")
+ required_version = LooseVersion("0.29.21")
if LooseVersion(cython_version) < required_version:
# too old or wrong cython, skip the test
cython = None
@@ -15,11 +15,11 @@ except ImportError:
else:
from distutils.version import LooseVersion
- # Cython 0.29.14 is required for Python 3.8 and there are
+ # Cython 0.29.21 is required for Python 3.9 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.
diff --git a/numpy/random/tests/test_extending.py b/numpy/random/tests/test_extending.py
index 77353463e..99a819efb 100644
--- a/numpy/random/tests/test_extending.py
+++ b/numpy/random/tests/test_extending.py
@@ -31,11 +31,11 @@ except ImportError:
cython = None
else:
from distutils.version import LooseVersion
# Cython 0.29.14 is required for Python 3.8 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.
# Note: keep in sync with the one in pyproject.toml
- required_version = LooseVersion('0.29.14')
+ required_version = LooseVersion('0.29.21')
if LooseVersion(cython_version) < required_version:
# too old or wrong cython, skip the test
cython = None
@@ -31,11 +31,11 @@ except ImportError:
else:
from distutils.version import LooseVersion
- # Cython 0.29.14 is required for Python 3.8 and there are
+ # Cython 0.29.21 is required for Python 3.9 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.
diff --git a/tools/cythonize.py b/tools/cythonize.py
index 65b79f716..6cebf0f72 100755
--- a/tools/cythonize.py
+++ b/tools/cythonize.py
@@ -66,11 +66,11 @@ def process_pyx(fromfile, tofile):
# check the version, and invoke through python
from distutils.version import LooseVersion
# Cython 0.29.14 is required for Python 3.8 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.
# Note: keep in sync with that in pyproject.toml
- required_version = LooseVersion('0.29.14')
+ required_version = LooseVersion('0.29.21')
if LooseVersion(cython_version) < required_version:
raise RuntimeError(f'Building {VENDOR} requires Cython >= {required_version}')
@@ -66,11 +66,11 @@ def process_pyx(fromfile, tofile):
# check the version, and invoke through python
from distutils.version import LooseVersion
- # Cython 0.29.14 is required for Python 3.8 and there are
+ # Cython 0.29.21 is required for Python 3.9 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.